NB: *please* make an issue prior to embarking on any significant effort towards
a pull request. This will serve as a unified place for discussion and hopefully
make sure that the change seems reasonable to merge once its implementation is
complete.

## Description

A few sentences describing the overall goals of the pull request's commits.

## Status

**READY/IN DEVELOPMENT**

## Related Issues

- [First related issue](https://github.com/n8henrie/fauxmo/issues/1)

## Todos

- [ ] Tests
- [ ] Documentation

## Steps to Test or Reproduce

E.g.:

```bash
git checkout -b <feature_branch> master
git pull https://github.com/<user>/fauxmo.git <feature_branch>
pytest tests/
```

## Other notes


